@@ -1,6 +1,7 @@
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
-Main interface for pricing service client
+Type annotations for pricing service client.
+
+[Open documentation](./client.md)
 
 Usage::
 
@@ -16,12 +17,8 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_pricing.paginator import (
-    DescribeServicesPaginator,
-    GetAttributeValuesPaginator,
-    GetProductsPaginator,
-)
-from mypy_boto3_pricing.type_defs import (
+from .paginator import DescribeServicesPaginator, GetAttributeValuesPaginator, GetProductsPaginator
+from .type_defs import (
     DescribeServicesResponseTypeDef,
     FilterTypeDef,
     GetAttributeValuesResponseTypeDef,
@@ -56,7 +53,8 @@ class Exceptions:
 
 class PricingClient:
     """
-    [Pricing.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -64,7 +62,8 @@ class PricingClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def describe_services(
@@ -75,7 +74,8 @@ class PricingClient:
         MaxResults: int = None,
     ) -> DescribeServicesResponseTypeDef:
         """
-        [Client.describe_services documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Client.describe_services)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Client.describe_services)
+        [Show boto3-stubs documentation](./client.md#describe_services)
         """
 
     def generate_presigned_url(
@@ -86,14 +86,16 @@ class PricingClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_attribute_values(
         self, ServiceCode: str, AttributeName: str, NextToken: str = None, MaxResults: int = None
     ) -> GetAttributeValuesResponseTypeDef:
         """
-        [Client.get_attribute_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Client.get_attribute_values)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Client.get_attribute_values)
+        [Show boto3-stubs documentation](./client.md#get_attribute_values)
         """
 
     def get_products(
@@ -105,7 +107,8 @@ class PricingClient:
         MaxResults: int = None,
     ) -> GetProductsResponseTypeDef:
         """
-        [Client.get_products documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Client.get_products)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Client.get_products)
+        [Show boto3-stubs documentation](./client.md#get_products)
         """
 
     @overload
@@ -113,7 +116,7 @@ class PricingClient:
         self, operation_name: Literal["describe_services"]
     ) -> DescribeServicesPaginator:
         """
-        [Paginator.DescribeServices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Paginator.DescribeServices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Paginator.DescribeServices)[Show boto3-stubs documentation](./paginators.md#describeservicespaginator)
         """
 
     @overload
@@ -121,11 +124,11 @@ class PricingClient:
         self, operation_name: Literal["get_attribute_values"]
     ) -> GetAttributeValuesPaginator:
         """
-        [Paginator.GetAttributeValues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues)[Show boto3-stubs documentation](./paginators.md#getattributevaluespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_products"]) -> GetProductsPaginator:
         """
-        [Paginator.GetProducts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Paginator.GetProducts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Paginator.GetProducts)[Show boto3-stubs documentation](./paginators.md#getproductspaginator)
         """
