@@ -1,6 +1,7 @@
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
-Main interface for pricing service client paginators.
+Type annotations for pricing service client paginators.
+
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -25,7 +26,7 @@ from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_pricing.type_defs import (
+from .type_defs import (
     DescribeServicesResponseTypeDef,
     FilterTypeDef,
     GetAttributeValuesResponseTypeDef,
@@ -38,7 +39,7 @@ __all__ = ("DescribeServicesPaginator", "GetAttributeValuesPaginator", "GetProdu
 
 class DescribeServicesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeServices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Paginator.DescribeServices)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Paginator.DescribeServices)[Show boto3-stubs documentation](./paginators.md#describeservicespaginator)
     """
 
     def paginate(
@@ -48,26 +49,28 @@ class DescribeServicesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeServicesResponseTypeDef]:
         """
-        [DescribeServices.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Paginator.DescribeServices.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Paginator.DescribeServices.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describeservicespaginator)
         """
 
 
 class GetAttributeValuesPaginator(Boto3Paginator):
     """
-    [Paginator.GetAttributeValues documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues)[Show boto3-stubs documentation](./paginators.md#getattributevaluespaginator)
     """
 
     def paginate(
         self, ServiceCode: str, AttributeName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[GetAttributeValuesResponseTypeDef]:
         """
-        [GetAttributeValues.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Paginator.GetAttributeValues.paginate)
+        [Show boto3-stubs documentation](./paginators.md#getattributevaluespaginator)
         """
 
 
 class GetProductsPaginator(Boto3Paginator):
     """
-    [Paginator.GetProducts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Paginator.GetProducts)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Paginator.GetProducts)[Show boto3-stubs documentation](./paginators.md#getproductspaginator)
     """
 
     def paginate(
@@ -78,5 +81,6 @@ class GetProductsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetProductsResponseTypeDef]:
         """
-        [GetProducts.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.3/reference/services/pricing.html#Pricing.Paginator.GetProducts.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/pricing.html#Pricing.Paginator.GetProducts.paginate)
+        [Show boto3-stubs documentation](./paginators.md#getproductspaginator)
         """
